/*
 * BustaGrahics.cpp
 * Busta' Sandwich Graphics Engine Implementation
 * Authors: Julian Chan, Thomas Patecky
 *
 * Created: 6:03 pm,July 15, 2005
 * Last Modified: July 15, 2005
 *
 */

#include "BustaGraphics.h"
#include <stdio.h>
#include <stdlib.h>


BustaGraphics::BustaGraphics()
{
	myScreen = SDL_SetVideoMode(800,600,32,SDL_SWSURFACE|SDL_RESIZABLE|SDL_HWPALETTE);
	mySprites = new BustaGraphicsSprites();
	myFont = new SFont(mySprites->getBMPFont());
	initButtonLocs();

	//Animations
	overall_anim_frame = 0;
	chef_anim_frame = 0;
	customer_anim_frame = 0;
}

/*
BustaGraphics::BustaGraphics(SDL_Surface* screen)
{
myScreen = screen;
	mySprites = new BustaGraphicsSprites();
	myFont = new SFont(mySprites->getBMPFont(0));
	myLogoFont = new SFont(mySprites->getBMPFont());
	initButtonLocs();
}
*/

void BustaGraphics::drawSPGame(BustaModelGameState* gs)
{
		clearScreen(SP_BG_COLOR);
		drawBoard(gs);
		drawScore(gs->getScore());
		drawChef(gs->getChef());
		drawCustomer(CUSTOMER_POS_X, CUSTOMER_POS_Y, gs->getCustomer(0));
		drawHealthBar(HEALTH_BAR_POS_X, HEALTH_BAR_POS_Y, gs->getChef()->getHealth(), CHEF_MAX_HEALTH);
		drawOrder(ORDER_POS_X, ORDER_POS_Y, gs->getCustomer(0)->getOrder());
		drawTipJar(TIP_JAR_POS_X, TIP_JAR_POS_Y, gs->getTipJar());
		drawCursor(gs->getCursor()->getPosition()->getX(), gs->getCursor()->getPosition()->getY(), gs->getCursor()->getAlignment());
		SDL_Flip(myScreen);

		overall_anim_frame++;
}

void BustaGraphics::clearScreen(Uint32 color)
{
		SDL_FillRect(myScreen, NULL, color);
}


void BustaGraphics::drawBoard(BustaModelGameState* gs)
{
		for(int row=0; row<BOARD_SIZE; row++)
				for(int col=0; col<BOARD_SIZE; col++)
						drawFoodPiece(gs->getBoard(row, col), 
									BOARD_TOP_LEFT_X + col * (FOOD_PIECE_GAP + FOOD_PIECE_SIZE),
									BOARD_TOP_LEFT_Y + row * (FOOD_PIECE_GAP + FOOD_PIECE_SIZE)	);
}

//Draws one FoodPiece
void BustaGraphics::drawFoodPiece(BustaModelFoodPiece* food_piece, int x, int y)
{
		SDL_Rect rect;

		rect.x = x;
		rect.y = y;

		updateRect(&rect, mySprites->getFoodSprite(food_piece));
}

void BustaGraphics::drawScore(int score)
{
		char score_str[16];
		sprintf(score_str, "Score: %d", score);
		myFont->write(myScreen, score_str, SCORE_POS_X, SCORE_POS_Y);
}


void BustaGraphics::drawCursor(int row, int col, int swap_alingment)
{
		SDL_Rect cursor_rect;
		
		//Draw the main cursor
		cursor_rect.x = BOARD_TOP_LEFT_X + col * (FOOD_PIECE_GAP + FOOD_PIECE_SIZE);
		cursor_rect.y = BOARD_TOP_LEFT_Y + row * (FOOD_PIECE_GAP + FOOD_PIECE_SIZE);
		updateRect(&cursor_rect, mySprites->getCursorSprites());
		
		//Draw the swap cursor
		switch (swap_alingment)
		{
				case LEFT:	col--; break;
				case RIGHT: col++; break;
				case UP:	row--; break;
				case DOWN:	row++; break;
		}
		cursor_rect.x = BOARD_TOP_LEFT_X + col * (FOOD_PIECE_GAP + FOOD_PIECE_SIZE);
		cursor_rect.y = BOARD_TOP_LEFT_Y + row * (FOOD_PIECE_GAP + FOOD_PIECE_SIZE);
		updateRect(&cursor_rect, mySprites->getSwapCursorSprites());
}

void BustaGraphics::drawChef(BustaModelChef* c)
{
		SDL_Rect rect;
		rect.x = CHEF_TOP_LEFT_POS_X;
		rect.y = CHEF_TOP_LEFT_POS_Y;

		ANIM_CHEF_TYPES state;

		if (c->getHealth() < 10)
				state = CHEF_DYING;
		else if (c->getHealth() < 70)
				state = CHEF_BLOATED;
		else
				state = CHEF_HEALTHY;

		//draw the current frame
		updateRect(&rect, mySprites->getChefSprites(state, chef_anim_frame));
		
		//increment to the next chef animation frame if frame delay has been met
		//Warning: crazy math ahead. It works because C evaluate any int < 1 as zero.
		chef_anim_frame += (overall_anim_frame % ANIM_CHEF_DELAY) / (ANIM_CHEF_DELAY-1);
		//loop the animation
		chef_anim_frame %= ANIM_CHEF_NUM_FRAMES; 
}

//Only draws the content state for now
void BustaGraphics::drawCustomer(int x, int y, BustaModelCustomer* customer)
{
		SDL_Rect rect;
		rect.x = x;
		rect.y = y;

		ANIM_CUSTOMER_STATES state;

		
		if (customer->getTime() < 10)
				state = CUSTOMER_PISSED;
		else
				state = CUSTOMER_CONTENT;


		updateRect(&rect, mySprites->getCustomerSprites(state, customer_anim_frame));
		//increment to the next chef animation frame if frame delay has been met
		//Warning: crazy math ahead. It works because C evaluate any int < 1 as zero.
		customer_anim_frame += (overall_anim_frame % ANIM_CUSTOMER_DELAY) / (ANIM_CUSTOMER_DELAY - 1);
		//loop the animation
		customer_anim_frame %= CUSTOMER_NUM_FRAMES; 
}

void BustaGraphics::drawHealthBar(int x, int y,int health, int max_health)
{
		SDL_Rect rect;
		rect.x = x;
		rect.y = y;
		rect.h = HEALTH_BAR_HEIGHT;

		//Draw the background
		rect.w = HEALTH_BAR_WIDTH;
		SDL_FillRect(myScreen, &rect, HEALTH_BAR_BG_COLOR);
	
		//Draw the "blood" remaining. i.e. the foreground
		rect.w = HEALTH_BAR_WIDTH * health / max_health;
		SDL_FillRect(myScreen, &rect, HEALTH_BAR_FG_COLOR);
}

void BustaGraphics::drawOrder(int x, int y, BustaModelFoodPiece** order_array)
{
		//Draws an overlapping array of food pieces
		for (int i=0; i<ORDER_LENGTH; i++)
			drawFoodPiece(order_array[i], x + (ORDER_OVERLAP * i), y);
}


void BustaGraphics::updateRect(SDL_Rect* rect, SDL_Surface* rectSurface)
{
		SDL_BlitSurface(rectSurface, NULL, myScreen, rect);
}

//Single-Player Game

void BustaGraphics::drawTipJar(int x , int y, BustaModelTipJar* tj)
{
		SDL_Rect rect;
		rect.x = x;
		rect.y = y;

		int percent_full = 100 * tj->getTips() / tj->getSize();
		updateRect(&rect, mySprites->getTipJarSprite(percent_full));

}

//Multi-Player Game
void BustaGraphics::drawMPGame(BustaModelGameState gs)
{
		printf("Called drawMPGame\n");
}
void BustaGraphics::drawOpponentBoard(BustaModelGameState gs)
{
		printf("Called drawOpponentBoard\n");
}

//Other screens
void BustaGraphics::drawMainScreen(MainScrnButton selected)
{
		clearScreen(MS_BG_COLOR_BLUE);

		//Draw Logo
		SDL_Rect rect;
		rect.x = MS_LOGO_POS_X;
		rect.y = MS_LOGO_POS_Y;
		updateRect(&rect, mySprites->getMainScreenLogo());
		
		//Draw User Selections
		myFont->writeCentered(myScreen, "Single Player", bMainScrn[MS_START_SP].box.y);
		myFont->writeCentered(myScreen, "Multi Player", bMainScrn[MS_START_MP].box.y);
		myFont->writeCentered(myScreen, "High Scores", bMainScrn[MS_HIGH_SCORE].box.y);
		myFont->writeCentered(myScreen, "Options", bMainScrn[MS_OPTIONS].box.y);
		myFont->writeCentered(myScreen, "Quit", bMainScrn[MS_QUIT].box.y);
		
		//Draw a slice of cheese next to the current user selection
		BustaModelFoodPiece* cheese = new BustaModelFoodPiece();
		cheese->setType(CHEESE);
		rect.x = MS_START_SP_POS_X - FOOD_PIECE_SIZE;
		//(FOOD_PIECE_SIZE/2) to center the cheese vertically
		rect.y = MS_START_SP_POS_Y - FOOD_PIECE_SIZE/2 + (MS_START_SP_H * selected);
		updateRect(&rect, mySprites->getFoodSprite(cheese));

		SDL_Flip(myScreen);
}


void BustaGraphics::drawChefSelelection()
{
		printf("Called drawChefSelection\n");
}
void BustaGraphics::drawHighScores()
{
		printf("Called drawHighScores\n");
}
void BustaGraphics::drawRankings()
{
		printf("Called drawRankings\n");
}
void BustaGraphics::drawOptions()
{
		printf("Called drawOptions\n");
}
void BustaGraphics::drawConnection()
{
		printf("Called drawConnection\n");
}

//button stuff
void BustaGraphics::initButtonLocs()
{
	bMainScrn[MS_START_SP].box.x = MS_START_SP_POS_X;
	bMainScrn[MS_START_SP].box.y = MS_START_SP_POS_Y;
	bMainScrn[MS_START_SP].box.w = MS_START_SP_W;
	bMainScrn[MS_START_SP].box.h = MS_START_SP_H;
	bMainScrn[MS_START_SP].nextLink = &bMainScrn[MS_START_MP];
	bMainScrn[MS_START_SP].prevLink = &bMainScrn[MS_QUIT];

	bMainScrn[MS_START_MP].box.x = MS_START_MP_POS_X;
	bMainScrn[MS_START_MP].box.y = MS_START_MP_POS_Y;
	bMainScrn[MS_START_MP].box.w = MS_START_MP_W;
	bMainScrn[MS_START_MP].box.h = MS_START_MP_H;
	bMainScrn[MS_START_MP].nextLink = &bMainScrn[MS_HIGH_SCORE];
	bMainScrn[MS_START_MP].prevLink = &bMainScrn[MS_START_SP];

	bMainScrn[MS_HIGH_SCORE].box.x = MS_HIGH_SCORE_POS_X;
	bMainScrn[MS_HIGH_SCORE].box.y = MS_HIGH_SCORE_POS_Y;
	bMainScrn[MS_HIGH_SCORE].box.w = MS_HIGH_SCORE_W;
	bMainScrn[MS_HIGH_SCORE].box.h = MS_HIGH_SCORE_H;
	bMainScrn[MS_HIGH_SCORE].nextLink = &bMainScrn[MS_OPTIONS];
	bMainScrn[MS_HIGH_SCORE].prevLink = &bMainScrn[MS_START_MP];

	bMainScrn[MS_OPTIONS].box.x = MS_OPTIONS_POS_X;
	bMainScrn[MS_OPTIONS].box.y = MS_OPTIONS_POS_Y;
	bMainScrn[MS_OPTIONS].box.w = MS_OPTIONS_W;
	bMainScrn[MS_OPTIONS].box.h = MS_OPTIONS_H;
	bMainScrn[MS_OPTIONS].nextLink = &bMainScrn[MS_QUIT];
	bMainScrn[MS_OPTIONS].prevLink = &bMainScrn[MS_HIGH_SCORE];

	bMainScrn[MS_QUIT].box.x = MS_QUIT_POS_X;
	bMainScrn[MS_QUIT].box.y = MS_QUIT_POS_Y;
	bMainScrn[MS_QUIT].box.w = MS_QUIT_W;
	bMainScrn[MS_QUIT].box.h = MS_QUIT_H;
	bMainScrn[MS_QUIT].nextLink = &bMainScrn[MS_START_SP];
	bMainScrn[MS_QUIT].prevLink = &bMainScrn[MS_OPTIONS];
	
}


			
		
