#include "BustaGraphicsSprites.h"


//Load all the sprites
BustaGraphicsSprites::BustaGraphicsSprites()
{
		LoadMainScreenLogo();
		LoadFoodPieces();
		LoadFonts();
		LoadChefSprites();
		LoadCursorSprites();
		LoadTipJarSprites();
		LoadCustomerSprites();
		printf("all loading done.\n");
}

void BustaGraphicsSprites::ApplyTransparency(SDL_Surface* surface)
{
		//Set the transparent key
		SDL_SetColorKey(surface, SDL_SRCCOLORKEY, SDL_MapRGB(surface->format, TRANSPARENT_KEY_R, TRANSPARENT_KEY_G, TRANSPARENT_KEY_B));
}

//Only loads Chef0 for now
void BustaGraphicsSprites::LoadChefSprites()
{
		char filename[MAX_FILE_LENGTH];	

		char* chef_states[CHEF_NUM_STATES] = {
				"Healthy",
				"Bloated",
				"Dying"};
	
		//Load the Idle sprites
		for (int chef_ID=0; chef_ID<NUM_CHEFS; chef_ID++)
		{
			for (int state=0; state<CHEF_NUM_STATES; state++)
			{
	
				for (int frame=0; frame<ANIM_CHEF_NUM_FRAMES; frame++)
				{
						sprintf(filename, "%s/%s/Chef%d/%s/%d.bmp", PATH_SPRITES, PATH_CHEF_SPRITES, chef_ID, chef_states[state] , frame);
						if ( (chef_sprites[chef_ID][state][frame] = SDL_LoadBMP(filename)) == NULL)
								printf("Chef Sprites Load Failed on %s!\n", filename);
	
						ApplyTransparency(chef_sprites[chef_ID][state][frame]);
				}
			}
		}
}

//Returns the proper sprite for the chef
//**Only returns sprites for Chef0 for now!
SDL_Surface* BustaGraphicsSprites::getChefSprites(ANIM_CHEF_TYPES state, int frame)
{
		return chef_sprites[0][state][frame];
}

//Returns the proper sprite for the customer
//**Only returns sprites for Patron0 for now!
SDL_Surface* BustaGraphicsSprites::getCustomerSprites(ANIM_CUSTOMER_STATES state, int frame)
{
		return customer_sprites[0][state][frame];
}

//Loads the 4 stages of the tip jar
void BustaGraphicsSprites::LoadTipJarSprites()
{
		char filename[MAX_FILE_LENGTH];
		
		for (int i=0; i<TIP_JAR_STAGES; i++)
		{
			sprintf(filename, "%s/%s/%d-4Full.bmp", PATH_SPRITES, PATH_TIP_JAR, i);
			if ( (tip_jar_sprites[i] = SDL_LoadBMP(filename)) == NULL)
					printf("Tip jar sprites Load Failed. Filename: %s\n", filename);
			ApplyTransparency(tip_jar_sprites[i]);
		}
}

SDL_Surface* BustaGraphicsSprites::getTipJarSprite(int percent_full)
{
		int stage = 100/TIP_JAR_STAGES;

		//(percent_full - 1) so that it is always < 100
		return tip_jar_sprites[(percent_full-1)/stage];
}

void BustaGraphicsSprites::LoadMainScreenLogo()
{
		char filename[MAX_FILE_LENGTH];
		
		//Load the main cursor
		sprintf(filename, "%s/%s/%s", PATH_SPRITES, PATH_MAIN_SCREEN, BMP_MAIN_SCREEN_LOGO);
		if ( (main_screen_logo = SDL_LoadBMP(filename)) == NULL)
				printf("Main Screen Logo Load Failed. Filename: %s\n", filename);
		ApplyTransparency(main_screen_logo);
}

//Only loads Patron0 for now
void BustaGraphicsSprites::LoadCustomerSprites()
{
		char filename[MAX_FILE_LENGTH];	

		char* customer_states[CUSTOMER_NUM_STATES] = {
				"Content",
				"Pissed"};
	
		//Load the Idle sprites
		for (int customer_ID=0; customer_ID<NUM_CUSTOMERS; customer_ID++)
		{
			for (int state=0; state<CUSTOMER_NUM_STATES; state++)
			{
	
				for (int frame=0; frame<CUSTOMER_NUM_FRAMES; frame++)
				{
						sprintf(filename, "%s/%s/Patron%d/%s/%d.bmp", PATH_SPRITES, PATH_CUSTOMER_SPRITES, customer_ID, customer_states[state] , frame);
						if ( (customer_sprites[customer_ID][state][frame] = SDL_LoadBMP(filename)) == NULL)
								printf("Customer Sprites Load Failed on %s!\n", filename);
	
						ApplyTransparency(customer_sprites[customer_ID][state][frame]);
				}
			}
		}
}

void BustaGraphicsSprites::LoadCursorSprites()
{
		char filename[MAX_FILE_LENGTH];
		
		//Load the main cursor
		sprintf(filename, "%s/%s/0.bmp", PATH_SPRITES, PATH_CURSOR);
		if ( (cursor_sprites = SDL_LoadBMP(filename)) == NULL)
				printf("Cursor Load Failed. Filename: %s\n", filename);
		ApplyTransparency(cursor_sprites);
		
		//Load the swap cursor	
		sprintf(filename, "%s/%s/0.bmp", PATH_SPRITES, PATH_SWAP_CURSOR);
		if ( (swap_cursor_sprites = SDL_LoadBMP(filename)) == NULL)
				printf("Swap Cursor Load Failed. Filename: %s\n", filename);
		ApplyTransparency(swap_cursor_sprites);
}


//Load static FoodPiece sprites that resides in PATH_SPRITES/PATH_FOOD_PIECE_SPRITES/<FOOD>/
void BustaGraphicsSprites::LoadFoodPieces()
{
		char filename[MAX_FILE_LENGTH];
		//The file list of food sprites. Follows the order of the enum FoodType
		char* food_sprites_dirs[NUMFOODPIECES] = {
					"Tomato", 
					"Onion", 
					"Lettuce", 
					"Cheese",
					"Salami",
					"Chicken",
					"Turkey",
					"Ham",
					"Tofu",
					"Mayo",
					"Mustard",
					"Pickles"};

		//The different freshness states have different file names. 
		//Follows the order of the enum FoodFreshness
		char* fresh_state_files[FOOD_NUM_FRESH_STATES] = {
					"fresh.bmp",
					"stale.bmp",
					"rotten.bmp"};
	
		for (int piece=0; piece<NUMFOODPIECES; piece++)
		{
				for (int freshness=0; freshness<FOOD_NUM_FRESH_STATES; freshness++)
				{
					sprintf(filename, "%s/%s/%s/%s", PATH_SPRITES, PATH_FOOD_PIECE_SPRITES, food_sprites_dirs[piece], fresh_state_files[freshness]);
					if ( (food_sprites[piece][freshness] = SDL_LoadBMP(filename)) == NULL)
							printf("Sprites Load Failed on %s!\n", filename);
				
					ApplyTransparency(food_sprites[piece][freshness]);
				}
		}
}


//Load the BMP font that resides in PATH_SPRITES
void BustaGraphicsSprites::LoadFonts()
{
		char filename[MAX_FILE_LENGTH];
		sprintf(filename, "%s/%s", PATH_SPRITES, BMP_FONT);
		if ( (font = SDL_LoadBMP(filename)) == NULL)
				printf("Font Load Failed. Filename: %s\n", filename);
		ApplyTransparency(font);

}


//Returns the correct food sprite based the food_piece passed in
//**Only returns the fresh sprite for now
SDL_Surface* BustaGraphicsSprites::getFoodSprite(BustaModelFoodPiece* food_piece)
{
		return food_sprites[(int) food_piece->getType()][0];
}
