/*	Filename:		BustaModelFoodPiece.h
 *	Description:	Busta' Sandwich FoodPiece model.
 *
 */

#ifndef BUSTA_SANDWICH_FOODPIECE
#define BUSTA_SANDWICH_FOODPIECE
#include <time.h>
#include <stdlib.h>

#include "BustaModelAnimation.h"

/**
 *@enum BustaModelFoodType
 *@brief Type of food
 * 
 * Lists different kinds of food
 */
enum FoodType{TOMATO,ONION,LETTUCE,CHEESE,SALAMI,CHICKEN,TURKEY,HAM,TOFU,MAYO,MUSTARD,PICKLES, NUMFOODPIECES};

/**
 * @class BustaModelFoodPiece
 * @brief Food Piece model
 *
 * Model representing food piece, includes type, freshness state, timer
 */
class BustaModelFoodPiece
{
	public:
		/**
		 * @brief Constructor
		 *
		 * Initializes variables
		 */
		BustaModelFoodPiece();

		/**
		 * @brief Constructor
		 *
		 * Initializes variables, sets type of food piece to t, 
		 * state equal to s
		 */
		BustaModelFoodPiece(FoodType t, int s);
		
		
		
		/**
		 * @brief Constructor
		 *
		 * If seed value != 0 then its is a pseudo-random FoodPiece constructor,
		 * else it will always construct the same FoodPiece() as long as seed != 0  
		 */
		BustaModelFoodPiece(int seed);

		BustaModelFoodPiece(FoodType t, int s, bool a);




		/**
		 * @brief Destructor
		 *
		 * Destructor
		 *
		 */
		~BustaModelFoodPiece();


		/**
		 * @brief FoodPiece type
		 *
		 * Gets the type of FoodPiece
		 */
		FoodType getType();

		/**
		 * @brief Sets FoodPiece type
		 *
		 * Sets the type of FoodPiece
		 */
		void setType(FoodType t);
		
		/**
		 * @brief Freshness state
		 *
		 * Returns the current FoodPiece freshness state
		 */
		int getState();

		
		/**
		 * @brief Sets freshness state
		 *
		 * Sets the current FoodPiece freshness state
		 */
		void setState(int s);

		/**
		 * @brief Gets immobility
		 *
		 * Returns boolean, saying whether the foodpiece can be swapped around the board or not
		 */
		bool getImmobile();

		/**
		 * @brief Sets immobility
		 *
		 * Sets whether the foodpiece can be swapped around the board
		 */
		void setImmobile(bool i);


	private:
		FoodType type;
		int state;
		bool immobile;
		

};

#endif