/*	Filename:		BustaModelGameState.h
 *	Description:	Busta' Sandwich GameState model.
 *
 */

#define NULL 0

#define HEIGHT 5
#define WIDTH 5
#define NUMCUSTOMERS 3

#ifndef BUSTA_SANDWICH_GAMESTATE
#define BUSTA_SANDWICH_GAMESTATE

#include <stdio.h>
#include <time.h>
#include <stdlib.h>
#include "BustaModelFoodPiece.h"
#include "BustaModelCustomer.h"
#include "BustaModelTipJar.h"
#include "BustaModelChef.h"
#include "BustaModelCursor.h"

/**
 * @class BustaModelGameState
 * @brief Model representing entire game state
 * 
 * Model representing entire game state, has score, tipjar, chef, customer queue	
 */
class BustaModelGameState
{
	public:
		/**
		 * @brief Constructor
		 *
		 * Initializes variables
		 */
		BustaModelGameState();

		/**
		 * @brief Destructor
		 *
		 *	Deletes models
		 */
		~BustaModelGameState();


		/**
		 * @brief Gets score
		 *
		 *  Gets the score of the player
		 */
		int getScore();

		/**
		 * @brief Sets score
		 *
		 * Sets the score of the player
		 */
		void setScore(int s);

		/**
		 * @brief Adds customer
		 *
		 * Adds a Customer to the queue, if more than two Customers deletes the oldest one
		 */
		void addCustomer(BustaModelCustomer* c);
		
		/**
		 * @brief Deletes customer
		 *
		 * Deletes the specified customer
		 */
		int removeCustomer(BustaModelCustomer* c);

		/**
		 * @brief Gets customer in queue
		 *
		 * Returns a pointer to the customer in the nth location in the queue
		 */
		BustaModelCustomer*  getCustomer(int n);

		/**
		 * @brief Gets tip jar
		 *
		 * Returns a pointer to the tip jar
		 */
		BustaModelTipJar* getTipJar();

		/**
		 * @brief gets Foodpiece in board
		 *
		 * Returns a pointer to the FoodPiece in the specified row and column
		 */
		BustaModelFoodPiece* getBoard(int i,int j);

		/**
		 * @brief gets the chef
		 *
		 * Returns a pointer to the chef
		 */
		BustaModelChef* getChef();

		/**
		 * @brief Gets cursor
		 *
		 * Returns a pointer to the cursor
		 */
		BustaModelCursor* getCursor();

		/**
		 * @brief Sets board location to specified foodPiece
		 *
		 * For specified board location, removes current foodpiece and sets to FoodPiece fp
		 */
		void setBoard(int i,int j, BustaModelFoodPiece* fp);

		/**
		 * @brief Deletes foodpiece on board
		 *
		 * Deletes the foodpiece in the specified location
		 */
		void removeFromBoard(int i, int j);

	private:
		int score;
		BustaModelFoodPiece* board[HEIGHT][WIDTH];
		BustaModelCustomer* customers[NUMCUSTOMERS];
		BustaModelTipJar* tips;
		BustaModelChef* chef;
		BustaModelCursor* cursor;
};

#endif
