/*	Filename:		BustaNetInternal.cpp
 *	Description:	Provides the implementation of all internal message classes between the
 *					network client and game engine.
 *
 */

#include "BustaNetInternal.h"

// --------------------------------------------------------------------------------------
// --------------------------- BustaNetInternalMsg (Base) -------------------------------
// --------------------------------------------------------------------------------------
int BustaNetInternalMsg::getType()
{
	return type;
}

void BustaNetInternalMsg::setType(int newType)
{
	type = newType;
}

// --------------------------------------------------------------------------------------
// ------------------------------- MPSpecialSandwich ------------------------------------
// --------------------------------------------------------------------------------------
MPSpecialSandwich::MPSpecialSandwich(int sendID, int receiveID, SpecialSandwich sSandwich)
{
	type = 301;
	senderID = sendID;
	receiverID = receiveID;
	specialSandwich = sSandwich;
}

int MPSpecialSandwich::getReceiverID()
{
	return receiverID;
}

int MPSpecialSandwich::getSenderID()
{
	return senderID;
}

SpecialSandwich MPSpecialSandwich::getSpecialSandwich()
{
	return specialSandwich;
}

// --------------------------------------------------------------------------------------
// -------------------------------- MPCharSelected --------------------------------------
// --------------------------------------------------------------------------------------
MPCharSelected::MPCharSelected(int pID, char selectedChar)
{
	type = 101;
	playerID = pID;
	character = selectedChar;
}

int MPCharSelected::getPlayerID()
{
	return playerID;
}

char MPCharSelected::getSelectedChar()
{
	return character;
}

// --------------------------------------------------------------------------------------
// ------------------------------ MPCharSelectCursor ------------------------------------
// --------------------------------------------------------------------------------------
MPCharSelectCursor::MPCharSelectCursor(int pID, BustaModelPosition pCursor)
{
	type = 102;
	playerID = pID;
	playerCursor = pCursor;
}

int MPCharSelectCursor::getPlayerID()
{
	return playerID;
}

BustaModelPosition MPCharSelectCursor::getCursor()
{
	return playerCursor;
}

// --------------------------------------------------------------------------------------
// ------------------------------- MPCharSelectMode -------------------------------------
// --------------------------------------------------------------------------------------
MPCharSelectMode::MPCharSelectMode()
{
	type = 201;
}

// --------------------------------------------------------------------------------------
// --------------------------------- MPStartGame ----------------------------------------
// --------------------------------------------------------------------------------------
MPStartGame::MPStartGame()
{
	type = 202;
}

// --------------------------------------------------------------------------------------
// ---------------------------------- MPEndGame -----------------------------------------
// --------------------------------------------------------------------------------------
MPEndGame::MPEndGame()
{
	type = 203;
}

// --------------------------------------------------------------------------------------
// --------------------------------- MPPlayerLost ---------------------------------------
// --------------------------------------------------------------------------------------
MPPlayerLost::MPPlayerLost(int pID)
{
	type = 204;
	playerID = pID;
}

int MPPlayerLost::getPlayerID()
{
	return playerID;
}

// --------------------------------------------------------------------------------------
// ------------------------------- MPConnectResponse ------------------------------------
// --------------------------------------------------------------------------------------
MPConnectResponse::MPConnectResponse(bool accept, char* msg, int cID)
{
	type = 1;
	acceptance = accept;
	reason = msg;
	clientID = cID;
}

bool MPConnectResponse::getAcceptance()
{
	return acceptance;
}

int MPConnectResponse::getClientID()
{
	return clientID;
}

char* MPConnectResponse::getReason()
{
	return reason;
}

// --------------------------------------------------------------------------------------
// ---------------------------------- MPNewPlayer ---------------------------------------
// --------------------------------------------------------------------------------------
MPNewPlayer::MPNewPlayer(int pID, char* pName)
{
	type = 2;
	playerID = pID;
	playerName = pName;
}

int MPNewPlayer::getPlayerID()
{
	return playerID;
}

char* MPNewPlayer::getPlayerName()
{
	return playerName;
}

// --------------------------------------------------------------------------------------
// ------------------------------- MPPlayerDisconnect -----------------------------------
// --------------------------------------------------------------------------------------
MPPlayerDisconnect::MPPlayerDisconnect(int pID, char* msg)
{
	type = 3;
	playerID = pID;
	reason = msg;
}

int MPPlayerDisconnect::getPlayerID()
{
	return playerID;
}

char* MPPlayerDisconnect::getReason()
{
	return reason;
}

// --------------------------------------------------------------------------------------
// --------------------------------- MPServerSettings -----------------------------------
// --------------------------------------------------------------------------------------
MPServerSettings::MPServerSettings(char* sName, int nClients, netClient** sClients)
{
	type = 4;
	serverName = sName;
	numClients = nClients;
	clients = sClients;
}

MPServerSettings::~MPServerSettings()
{
	// free memory allocated for each client
	for (int i = 0; i < numClients; i++)
	{
		free(clients[i]);
	}
}

netClient* MPServerSettings::getClient(int index)
{	
	if ( (index < 0) || (index > numClients) )
		return NULL;
	else
		return clients[index];
}

netClient** MPServerSettings::getClients()
{
	return clients;
}

int MPServerSettings::getNumClients()
{
	return numClients;
}

char* MPServerSettings::getServerName()
{
	return serverName;
}

void MPServerSettings::setServerName(char* newName)
{
	serverName = newName;
}

