/*	Filename:		BustaNetMsgQ.cpp
 *	Description:	Internal network message queue implementation.
 *
 */

#include "BustaNetMsgQ.h"
#include <stdlib.h>

BustaNetMsgQ::BustaNetMsgQ()
{
	nodeCount = 0;		// no nodes in queue
	headNode = NULL;	// no head node
	tailNode = NULL;	// no tail node
}

BustaNetMsgQ::~BustaNetMsgQ()
{
	flushQ();		// empty the queue
	headNode = NULL;
	tailNode = NULL;
}

void BustaNetMsgQ::enqueue(BustaNetMsgQNode* newNode)
{
	newNode->setNext(NULL);			// last node has no next
	tailNode->setNext(newNode);		// add it after the current last node
	tailNode = newNode;				// point to the new last node
	nodeCount++;					// increment the count of nodes
}

void BustaNetMsgQ::flushQ()
{
	BustaNetMsgQNode* nodePtr;		// node pointer

	nodePtr = headNode;				// get the head node

	// while there are still nodes in the list
	while (nodePtr != NULL)
	{
		headNode = headNode->getNext();		// move the head pointer down the list
		delete(nodePtr->getMsg());			// delete the node's message
		delete(nodePtr);					// delete the head node
		nodePtr = headNode;					// get the new head node
	}

	nodeCount = 0;				// reset count of nodes in queue
}

int BustaNetMsgQ::getNodeCount()
{
	return nodeCount;
}

BustaNetInternalMsg* BustaNetMsgQ::pop()
{
	BustaNetInternalMsg* tempMsg;	// temporary msg pointer
	BustaNetMsgQNode* tempNode;		// temporary node pointer

	tempMsg = headNode->getMsg();	// get the head node's msg
	tempNode = headNode;			// get the head node

	headNode = headNode->getNext();	// remove the head node from the queue
	delete(tempNode);				// delete the former head node

	return tempMsg;					// return the message
}

