/*	Filename:		BustaNetMsgQNode.h
 *	Description:	Message queue node definition
 *
 */

#ifndef BUSTASANDWICH_NETMSG_Q_NODE
#define BUSTASANDWICH_NETMSG_Q_NODE

#include "BustaNetInternal.h"
//class BustaNetInternalMsg;

/**
 * @class BustaNetMsgQNode
 * @brief Network Message Queue Node
 *
 * The class represents a node of the message queue.  Each node contains an internal message.
 *
 * @see BustaNetMsgQ
 * @see BustaNetInternalMsg
 */
class BustaNetMsgQNode
{
	public:
		/**
		 * @brief CONSTRUCTOR
		 *
		 * Creates an empty message node.
		 */
		BustaNetMsgQNode();

		/**
		 * @brief CONSTRUCTOR
		 *
		 * Creates a message node containing the message newMsg
		 */
		BustaNetMsgQNode(BustaNetInternalMsg* newMsg);

		/**
		 * @brief DESTRUCTOR
		 *
		 * Deletes the node.
		 *
		 * @warning The message queue structure is NOT kept after this node's deletion!
		 * @warning The associated message is NOT deleted along with the node!
		 */
		~BustaNetMsgQNode();

		/**
		 * @brief Returns the message contained in the node
		 *
		 * Returns the message associated with the message node.
		 *
		 * @return A BustaNetInternalMsg pointer referencing an internal message
		 *
		 * @see BustaaNetInternalMsg
		 */
		BustaNetInternalMsg* getMsg();

		/**
		 * @brief Returns a pointer to the next node
		 *
		 * Returns a pointer to the next node in the message queue.
		 *
		 * @return A pointer to the next node in the message queue
		 */
		BustaNetMsgQNode* getNext();

		/**
		 * @brief Sets the next node after this node in the message queue
		 *
		 * Sets the next node after this node in the message queue.
		 *
		 * @param newNextNode A pointer to the next node to be placed after this one in the queue
		 */
		void setNext(BustaNetMsgQNode* newNextNode);

	private:
		BustaNetInternalMsg* nodeMsg;	// The message contained in this node
		BustaNetMsgQNode* nextNode;		// The next node in the message queue
};

#endif